<template>
    <div class="loan-info-box">
        <x-header slot="header"
                  style="width:100%;height:46px;background-color: #ec6758"
                  title="银行卡绑定"
                  :left-options="{backText: '', preventGoBack:true}"
                  @on-click-back="goBackPage"
        ></x-header>
        <flow class="progressState">
            <flow-state state="1" title="填写资料" class="currentStep porcolor"></flow-state>
            <flow-line is-done></flow-line>
            <flow-state state="2" title="绑定银行卡" class="currentStep porcolor"></flow-state>
            <flow-line></flow-line>
            <flow-state state="3" title="照片上传"></flow-state>
            <flow-line></flow-line>
            <flow-state state="4" title="三方授权"></flow-state>
            <flow-line></flow-line>
            <flow-state state="5" title="提交申请"></flow-state>
        </flow>
        <div class="bankInfo_class">
            <group class="personInfo bankstyle" text-align="right">
                <x-input title="银行卡号"
                         :max="19"
                         :min="19"
                         placeholder="请输入银行卡号"
                         v-model.trim="bankin.bankCardNo"
                ></x-input>
                <selector
                    title="开户行"
                    :options="bankinfo"
                    placeholder="请选择"
                    v-model="bankin.bankName"
                ></selector>
                <!--<cell title="开户行"-->
                <!--v-model="bankin.bankName"-->
                <!--&gt;</cell>-->
                <x-input title="预留手机号"
                         :max="11"
                         :min="11"
                         type="tel"
                         is-type="china-mobile"
                         placeholder="请输入手机号"
                         v-model.trim="bankin.mblNo"
                ></x-input>
            </group>
            <group class="personInfo" text-align="right">
                <cell title="姓名"
                      v-model="bankin.userName"
                ></cell>
                <cell title="身份证号"
                      v-model="bankin.idNo"
                ></cell>
            </group>
            <div style="height: 20px"></div>
            <box gap="0 15px">
                <x-button type="primary" @click.native="handleUpStep">上一步</x-button>
                <x-button type="primary" @click.native="handleNextStep">下一步</x-button>
            </box>
            <div style="height: 20px"></div>
        </div>
    </div>
</template>
<script>
    import {
        Flow,
        FlowState,
        FlowLine,
        XHeader,
        Group,
        GroupTitle,
        Cell,
        XInput,
        Selector,
        XButton,
        Box,
        Actionsheet,
    } from 'vux';

    import FSpace from '../../../components/common/FSpace.vue';
    import validate from '../../../tool/validator';
    import SysApi from '../../../api/api'
    import statusCodeManage from '../../../api/statusCodeManage'

    export default {
        name: 'bankInfo',
        data() {
            return {
                bankin: {
                    bankCardNo: '',
                    bankName: '',
                    mblNo: '',
                    userName: '',
                    idNo: ''
                }, // 初始化的用户信息
                bankinfo: [
                    {code: '1', name: "工商银行"},
                    {code: '2', name: "农业银行"},
                    {code: '3', name: "中国银行"},
                    {code: '4', name: "建设银行"},
                    {code: '5', name: "交通银行"},
                    {code: '6', name: "中信银行"},
                    {code: '7', name: "光大银行"},
                    {code: '8', name: "广发银行"},
                    {code: '9', name: "招商银行"},
                    {code: '10', name: "兴业银行"},
                    {code: '11', name: "浦发银行"},
                    {code: '12', name: "上海银行"},
                    {code: '13', name: "宁波银行"},
                    {code: '14', name: "平安银行"},
                    {code: '15', name: "兰州银行"},
                    {code: '16', name: "包商银行"}
                ],
                isLastStep: false, // 是否是最后一步
                activePageItem: 0, // 激活当前页
                pageList: [], // 一共有几页
            };
        },
        computed: {},
        methods: {

            //初始化银行卡绑定
            BankCard() {
                this.bankinfo = this.getOptionsList(this.bankinfo);

                let _this = this;
                let prodId = {
                    prodId: this.$route.query.prodId,
                };
                SysApi.initBankCard(prodId).then(
                    res => {
                        console.log(res);
                        _this.bankin.bankCardNo = res.body.bankCardNo;
//                        _this.bankin.bankName = res.body.bankName;
                        _this.bankin.mblNo = res.body.mblNo;
                        _this.bankin.userName = res.body.userName;
                        _this.bankin.idNo = res.body.idNo;
                    }, error => {

                    })
            },
            //上一步跳转
            handleUpStep() {
                this.$router.push({
                    path: '/bnd/credit/passwordInfo', query: {prodId: this.$route.query.prodId}
                });
            },
            //下一步的表单验证及提交
            handleNextStep() {
                if (validate.checkValEmpty(this.bankin.bankCardNo)) {
                    this.validateTip('请输入银行卡号');
                    return false;
                }
                if (validate.checkValEmpty(this.bankin.mblNo)) {
                    this.validateTip('请输入预留手机号');
                    return false;
                }
                if (!validate.checkPhone(this.bankin.mblNo)) {
                    this.validateTip('请输入正确的预留手机号');
                    return false;
                }

                let _this = this;
                let bankin = {
                    prodId: this.$route.query.prodId,
                    bankCardNo: this.bankin.bankCardNo,
                    //这个东西等。。。。。。。。。。。。。。。
//                    bankName: this.bankin.bankName,
                    bankName: '招商银行',
                    mblNo: this.bankin.mblNo,
                    userName: this.bankin.userName,
                    idNo: this.bankin.idNo,
                };
                SysApi.saveBankCard(bankin).then(
                    res => {
                        this.$router.push({
                            path: '/bnd/credit/bindingCode', query: {prodId: this.$route.query.prodId}
                        });
                    }, error => {
                        statusCodeManage.showTipOfStatusCode(error)
                    }
                );
                sessionStorage.mblNo = this.bankin.mblNo
            },

            // 弹窗
            validateTip(errorMsg) {
                return this.$vux.toast.show({
                    width: 'auto',
                    type: 'text',
                    text: errorMsg,
                    time: 2000,
                    position: 'middle'
                });
            },
            // 得到选项列表统一的方法
            getOptionsList(optionList) {
                let tmpList = [];
                if (optionList instanceof Array) {
                    optionList.forEach(function (item) {
                        tmpList.push({
                            key: item.code,
                            value: item.name
                        });
                    });
                }
                return tmpList;
            },
            //返回上一页
            goBackPage() {
                // 如果是第一步的话，那么返回到上一个页面
                if (this.activePageItem <= 1) {
                    this.$router.back();
                    // 不是的话，那么显示上一步
                } else {
                    this.activePageItem--;
                    this.isLastStep = this.pageList.length === this.activePageItem;
                }
            },
        },
        activated: function () {
            this.BankCard();
        },
        components: {
            Group,
            GroupTitle,
            Cell,
            XInput,
            Selector,
            XHeader,
            XButton,
            Box,
            Flow,
            FlowState,
            FlowLine,
            Actionsheet,
            FSpace,
        }
    };
</script>

<style lang="less">
    @import "../../../style/mixin.less";

    .loan-info-box {
        background-color: @color-background-default;
        .vux-header {
            .color-linear-gradient(@color-primary-light, @color-primary, 90deg);
            .vux-header-left {
                .left-arrow:before {
                    border: solid 1px @color-white;
                    border-width: 2px 0 0 2px;
                }
            }
        }
        .progressState div p {
            font-size: @font-size-tiny;
        }
        .weui-wepay-flow__state {
            width: 16px;
            height: 16px;
            top: -1px;
            padding-top: 1px;
        }
        .currentStep .weui-wepay-flow__state {
            width: 16px;
            height: 16px;
            padding-top: 1px;
            border: 1px solid @color-primary;
            color: @color-primary;
            border-radius: 50%;
            background-color: @color-white;
        }
        .weui-input {
            height: 28px;
            line-height: 28px;
        }
        .weui-wepay-flow, .weui-wepay-flow-auto {
            padding: 10px 40px 30px;
            background: @color-white;
        }
        .weui-wepay-flow__li_done .weui-wepay-flow__state,
        .weui-wepay-flow__process {
            background-color: @color-primary;
        }
    }

    .weui-wepay-flow {
        background-color: @color-white;
    }

    .left-arrow:before {
        border-color: @color-white;
    }

    .weui-cells__title {
        margin: 0 !important;
        font-size: 16PX !important;
    }

    .weui-input, .weui-cell__bd {
        font-size: @font-size-base;
    }

    .weui-label {
        font-size: @font-size-base;
    }

    .personInfo ::-webkit-input-placeholder { /* WebKit browsers */
        color: #bfbfbf;
    }

    .personInfo :-moz-placeholder { /* Mozilla Firefox 4 to 18 */
        color: #bfbfbf;
    }

    .personInfo ::-moz-placeholder { /* Mozilla Firefox 19+ */
        color: #bfbfbf;
    }

    .personInfo :-ms-input-placeholder { /* Internet Explorer 10+ */
        color: #bfbfbf;
    }

    .header-space {
        height: 46px;
    }

    .loan-info-box .weui-cell_select .weui-select {
        padding-right: 2.5rem;
        direction: rtl;
    }

    .loan-info-box .weui-input {
        text-align: right !important;
        font-size: @font-size-medium;
    }

    .loan-info-box .weui-btn_primary {
        .color-linear-gradient(@color-primary-light, @color-primary, 90deg);
    }

    .loan-info-box .weui-btn_primary:not(.weui-btn_disabled):active {
        color: rgba(255, 255, 255, 0.6);
        background-color: rgb(241, 95, 79);;
    }

    /*------------------------------*/
    .vux-no-group-title {
        margin-top: 0.77rem !important;
    }

    .loan-info-box .currentStep .weui-wepay-flow__state {
        background-color: @color-primary;
        color: @color-white !important;
        line-height: 1rem;
    }

    .weui-wepay-flow__li.weui-wepay-flow__li .weui-wepay-flow__state {
        width: 1.33333rem;
        height: 1.33333rem;
        border-radius: 1.58333rem;
        color: @color-text-third;
        line-height: 1.33333rem;
    }

    .porcolor p {
        color: @color-primary;
    }

    .loan-info-box .weui-wepay-flow, .loan-info-box .weui-wepay-flow-auto {
        padding: 0.83333rem 2.33333rem 2.5rem;
    }

    select {
        font-size: @font-size-medium !important;
    }

    .weui-btn:after {
        border: none !important;
    }

    .personInfo {
        .vux-label {
            font-size: @font-size-base !important;
            color: #000;
        }
        .weui-cell__ft {
            font-size: @font-size-medium !important;
            color: #000;
        }
    }

    .weui-btn {
        font-size: @font-size-primary !important;
    }

</style>
